@@ -1,18 +1,16 @@
-context("wsj")
-
 test_that("theme_wsj works", {
-  expect_is(theme_wsj(), "theme")
+  expect_s3_class(theme_wsj(), "theme")
 })
 
 test_that("wsj_pal works", {
   p <- wsj_pal()
-  expect_is(p, "function")
-  expect_is(attr(p, "max_n"), "integer")
+  expect_type(p, "closure")
+  expect_type(attr(p, "max_n"), "integer")
   expect_hexcolor(p(3))
 })
 
 test_that("theme_wsj works", {
-  expect_is(theme_wsj(), "theme")
+  expect_s3_class(theme_wsj(), "theme")
 })
 
 test_that("theme_wsj raises error with invalid palette", {
@@ -20,9 +18,9 @@ test_that("theme_wsj raises error with invalid palette", {
 })
 
 test_that("scale_colour_wsj works", {
-  expect_is(scale_colour_wsj(), "ScaleDiscrete")
+  expect_s3_class(scale_colour_wsj(), "ScaleDiscrete")
 })
 
 test_that("scale_fill_wsj works", {
-  expect_is(scale_fill_wsj(), "ScaleDiscrete")
+  expect_s3_class(scale_fill_wsj(), "ScaleDiscrete")
 })
